@@ -40,6 +40,7 @@
 --excludefiles              ->  file to exclude file name (check documentation for the format) only for 'rfn, --replacefilename' \
                                 obfuscation feature
 -rth, --replacetohex        ->  enable 'replace string to hex' obfuscation feature (python 2 target files only)
+--version                   ->  check current version
 -v, --verbose               ->  improve verbosity
 
 """
@@ -69,6 +70,10 @@ except ModuleNotFoundError:
 
 #--------------------------------------------------------- [Global] ---------------------------------------------------------#
 
+__version__ = "1.0.10.4"
+
+#------------------------------------------------- [Function(s)/Class(es)] --------------------------------------------------#
+
 def main():
     if sys.version_info[0] != 3:
         print("\n" + Colors.ERROR + "[-] Intensio-Obfuscator only support Python 3.x" + Colors.DISABLE)
@@ -77,13 +82,18 @@ def main():
     args = Args()
     utils = Utils()
 
-    if len(sys.argv) > 1 and len(sys.argv) <= 19:
+    if len(sys.argv) > 1 and len(sys.argv) <= 20:
         pass
     else:
         print("\n" + Colors.ERROR + "[-] Incorrect number of arguments" + Colors.DISABLE + "\n")
         args.GetArgHelp()
         sys.exit(0)
 
+    if args.GetArgsValue().version:
+        print("\n[*] version : {}\n".format(__version__))
+        if len(sys.argv) == 2:
+            sys.exit(0)
+
     if args.GetArgsValue().input:
         if args.GetArgsValue().output:
             if re.match(Reg.detectMlenArg, str(args.GetArgsValue().mixerlength)):
